<template>
    <div>
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="500"
            :close-on-click-modal="false"
            :before-close="handleClose"
        >
            <el-form
                ref="formRef"
                style="max-width: 600px; margin: 0 auto"
                :model="formData"
                :rules="rules"
                label-width="auto"
            >
                <el-form-item label="煤种名称" prop="coal">
                    <el-input
                        v-model="formData.coal"
                        placeholder="请输入煤种名称"
                    />
                </el-form-item>
                <el-form-item label="维护人姓名" prop="maintainerId">
                    <el-input
                        v-model="formData.maintainerId"
                        placeholder="请输入维护人姓名"
                    />
                </el-form-item>
                <el-form-item label="维护日期" prop="maintenanceDate">
                    <el-input v-model="formData.maintenanceDate" placeholder="请输入银行账户" />
                </el-form-item>
                <el-form-item>
                    <el-button type="primary" @click="submitForm">
                        确定
                    </el-button>
                    <el-button v-if="addOrEdit === 'edit'" @click="resetForm">重置</el-button>
                    <el-button v-if="addOrEdit === 'add'" @click="cancelForm">取消</el-button>
                </el-form-item>
            </el-form>
        </el-dialog>
    </div>
</template>

<script setup>
import { ref, watch ,defineProps } from 'vue'
import { addOrEditCoalInfo } from '@/api/basicInformation/coal'

const props = defineProps({
    beforeClose: {
        type: Function,
        default: () => {}
    },
    form: {
        type: Object,
        default: () => ({})
    },
    addOrEdit: {
        type: String,
        default: 'add'
    },
    title: {
        type: String,
        default: ''
    },
})

const emit = defineEmits(['submit', 'handleBeforeClose','update:coalDialogFormVisible'])

// 表单引用
const formRef = ref(null)
// 表单数据
const formData = ref({ ...props.form })
// 弹窗可见性
const dialogVisible = defineModel("coalDialogFormVisible",{required:true,type:Boolean})

// 监听外部传入的表单数据变化
watch(() => props.form, (newVal) => {
    formData.value = { ...newVal }
}, { deep: true })

// 监听内部弹窗状态变化
watch(() => dialogVisible.value, (newVal) => {
    emit('update:coalDialogFormVisible', newVal)
})

// 提交表单
const submitForm = async () => {
    if (!formRef.value) return
    await formRef.value.validate(async (valid, fields) => {
        if (valid) {
            formData.value.maintenanceDate = "2023-10-01" // 示例日期
            let result = await addOrEditCoalInfo({
                ...formData.value,
            })
            let obj = {
                title: props.title,
                result,
            }
            emit('submit', obj)
        }
    })
}
// 取消表单
const cancelForm = () => {
    emit('update:coalDialogFormVisible', false)
    formData.value = {}
}
// 重置表单
const resetForm = () => {
    if (!formRef.value) return
    formRef.value.resetFields()
}
// 关闭弹窗
const handleClose = () => {
    // 触发父组件的关闭函数
    emit("handleBeforeClose")
    emit('update:coalDialogFormVisible', false)
}
const rules = reactive({
  supplierName: [
    { required: true, message: "请输入供货商名称", trigger: "blur" },
  ],
  identifyNumber: [
    { required: true, message: "请正确输入纳税人识别号", trigger: "blur" },
    { min: 17, max: 20, message: "请输入17-20位纳税人识别号", trigger: "blur" },
  ],
  address: [
    {
      required: true,
      message: "请选择经营地址",
      trigger: "change",
    },
  ],
  bankAccount: [{ required: true, message: "请输入银行账户", trigger: "blur" }],
  bank: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contacts: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contactsPhone: [
    { required: true, message: "请输入联系人", trigger: "blur" },
    { min: 11, max: 11, message: "请输入11位联系人电话", trigger: "blur" },
  ],
});
</script>

<style lang="sass" scoped>
</style>